@@ -3,7 +3,7 @@ from track.client import Client
 __version__ = VERSION
 
 """Settings"""
-write_key = None
+api_key = None
 default_client = None
 host = None
 sync_mode = False
@@ -14,15 +14,16 @@ on_error = None
 max_queue_size = 10000
 
 
-def identify(user_id=None, country_code='+91', phone_number=None, traits={}):
+def user(user_id=None, country_code='+91', phone_number=None, traits={}):
     """Send an identify call for customer"""
-    return _proxy('identify', user_id=user_id, country_code=country_code,
+    return _proxy('user', user_id=user_id, country_code=country_code,
                   phone_number=phone_number, traits=traits)
 
 
-def event(user_id=None, event=None, traits={}):
+def event(user_id=None, event=None, traits={}, country_code="+91", phone_number=None):
     """Send an event track call."""
-    return _proxy('event', user_id=user_id, event=event, traits=traits)
+    return _proxy('event', user_id=user_id, event=event, traits=traits,
+                  country_code=country_code, phone_number=phone_number)
 
 
 def flush():
@@ -45,7 +46,7 @@ def _proxy(method, *args, **kwargs):
     global default_client
     if not default_client:
         default_client = Client(
-            write_key=write_key,
+            write_key=api_key,
             host=host,
             debug=debug,
             sync_mode=sync_mode,
